package Business::RU;

use strict;
use warnings;

our $VERSION = '0.1';

1;

__END__

=pod

=head1 NAME

Business::RU

=head1 VERSION

version 0.1

=head1 DESCRIPTION

=over 4

=item L<Business::RU::BankAccount>

Validate BIC, current and correspondent accounts

=item L<Business::RU::INN>

Validate INN

=item L<Business::RU::OKPO>

Validate OKPO

=back

=head1 SEE ALSO

L<Moose>
L<Moose::Role>

=head1 BUGS

Please report any bugs through the web interface at L<http://rt.cpan.org> 
or L<https://github.com/GermanS/Business-RU>

=head1 AUTHOR

German Semenkov
german.semenkov@gmail.com

=head1 COPYRIGHT AND LICENSE

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut